@@ -2,7 +2,8 @@
 module.exports = {
   content: [
     "./src/components/**/*.{js,jsx,ts,tsx}",
-    "./src/pages/**/*.{js,jsx,ts,tsx}"
+    "./src/pages/**/*.{js,jsx,ts,tsx}",
+    "./src/pages/Content/index.js"
   ],
   theme: {
     extend: {},
